#include <cstring>
#include <cstdlib>
#include <cmath>
#include <iostream>
#include <fstream>
#include <string>
#include <vector>

using namespace std;

const int maxn = 200;

typedef vector<pair<int, int> > VPII;

struct output_structure
{
    int len;
    VPII ans[2];
    bool pe, wa;
    string comment;
};

int n, m;
string s[maxn];
output_structure ans, out;
int vis[maxn][maxn];

bool read(ifstream &f, VPII &res)
{
    int n;
    f >> n;
    if (!f || n < 0) return false;
    for (int i = 0; i < n; i++) {
        int x, y;
        f >> x >> y;
        if (!f) return false;
        res.push_back(make_pair(x, y));
    }
    return true;
}

bool check(const VPII &v, string &comment)
{
    int len = v.size();

    if (!len) {
        comment = "seq is empty";
        return false;
    }

    if (v[0].second != 1) {
        comment = "seq isn't started from the left side";
        return false;
    }
    if (v[len-1].second != m) {
        comment = "seq isn't finished at the right side";
        return false;
    }

    memset(vis, 0, sizeof(vis));
    for (int i = 0; i < len; i++) {
        if (vis[v[i].first-1][v[i].second-1]) {
            comment = "multiple usage";
            return false;
        }
        vis[v[i].first-1][v[i].second-1] = 1;
        if (!(1 <= v[i].first && v[i].first <= n && 1 <= v[i].second && v[i].second <= m)) {
            comment = "out of the field";
            return false;
        }
        if (s[v[i].first-1][v[i].second-1] == '.') {
            comment = "aqueduct uses empty cell";
            return false;
        }
        if (i && abs(v[i].first - v[i-1].first) + abs(v[i].second - v[i-1].second) != 1) {
            comment = "aqueduct connectivity failure";
            return false;
        }
    }

    return true;
}

void process(ifstream &f, output_structure &ou)
{
    string t;
    f >> t;
    if (!f) {
        ou.pe = true; 
        ou.comment = "couldn't read the first string"; 
        return;
    }

    if (t == "YES") {
	ou.len = 1;
        if (!read(f, ou.ans[0])) {
            ou.pe = true; 
            ou.comment = "YES, but couldn't read the sequence";
            return;
        }
        if (!check(ou.ans[0], ou.comment)) {
            ou.pe = false; 
            ou.wa = true; 
            return;
        }
    } else if (t == "MULTIPLE") {
	ou.len = 2;
        if (!read(f, ou.ans[0]) || !read(f, ou.ans[1])) {
            ou.pe = true; 
            ou.comment = "MULTIPLE, but couldn't read the seqs";
            return;
        }
        if (!check(ou.ans[0], ou.comment) || !check(ou.ans[1], ou.comment)) {
            ou.pe = false; 
            ou.wa = true; 
            return;
        }
        if (ou.ans[0] == ou.ans[1]) {
            ou.comment = "MULTIPLE, but seqs are equal";
            ou.pe = false; 
            ou.wa = true; 
            return;
        }
    } else if (t == "NO") {
	ou.len = 0;
    }
    ou.pe = false; ou.wa = false;
}

int main(int argc, char* argv[])
{
    ifstream f_in(argv[1]);
    ifstream f_out(argv[2]);
    ifstream f_ans(argv[3]);

    f_in >> n >> m;
    for (int i = 0; i < n; i++) f_in >> s[i];

    process(f_ans, ans);
    process(f_out, out);

    if (ans.pe) {
        cout << "jury got PE: " << ans.comment << endl;
        return 3; 
    }
    if (ans.wa) {
        cout << "jury got WA: " << ans.comment << endl;
        return 3; 
    }
    if (out.pe) {
        cout << "PE: " << out.comment << endl;
        return 2; 
    }
    if (out.wa) {
        cout << "WA: " << out.comment << endl;
        return 1; 
    }
    if (ans.len < out.len) {
        cout << "jury found less aqueducts" << endl;
        return 3;
    }
    if (ans.len > out.len) {
        cout << "contestant found less aqueducts" << endl;
        return 1;
    }

    cout << "ok ;)" << endl;
    return 0;
}
